@@ -4,7 +4,7 @@
  * GChemPaint library
  * application.cc
  *
- * Copyright (C) 2004-2012 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2014 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -24,7 +24,7 @@
 
 #include "config.h"
 #include "application.h"
-#include "atom.h"
+#include "atom-residue.h"
 #include "bond.h"
 #include "brackets.h"
 #include "document.h"
@@ -59,6 +59,7 @@
 #include <gcu/cmd-context.h>
 #include <gcu/loader.h>
 #include <gcu/loader-error.h>
+#include <gcu/xml-utils.h>
 #include <gccv/canvas.h>
 #include <glib/gi18n-lib.h>
 #include <fstream>
@@ -235,6 +236,11 @@ static Object* CreateAtom ()
 	return new Atom ();
 }
 
+static Object* CreateResidue ()
+{
+	return new AtomResidue ();
+}
+
 static Object* CreateBond ()
 {
 	return new Bond ();
@@ -317,6 +323,7 @@ bool	Application::m_HaveGChem3D = false;
 bool	Application::m_HaveAvogadro = false;
 
 extern TypeId ReactionSeparatorType;
+extern TypeId ReactionSubstractorType;
 extern TypeId StepCounterType;
 
 static void on_config_changed (GOConfNode *node, gchar const *key, Application *app)
@@ -349,6 +356,7 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 
 		// Initialize types
 		AddType ("atom", CreateAtom, AtomType);
+		AddType ("residue", CreateResidue, ResidueType);
 		AddType ("bond", CreateBond, gcu::BondType);
 		AddType ("molecule", CreateMolecule, MoleculeType);
 		AddType ("reaction", CreateReaction, ReactionType);
@@ -358,6 +366,7 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		AddType ("reaction-arrow", CreateReactionArrow, ReactionArrowType);
 		AddType ("reaction-operator", NULL, ReactionOperatorType);
 		ReactionSeparatorType = AddType ("reaction-separator", NULL, ReactionSeparatorType);
+		ReactionSubstractorType = AddType ("reaction-substractor", NULL, ReactionSubstractorType);
 		StepCounterType = AddType ("step-counter", NULL, StepCounterType);
 		ReactionPropType = AddType ("reaction-prop", CreateReactionProp);
 		MesomerType = AddType ("mesomer", CreateMesomer);
@@ -377,12 +386,14 @@ Application::Application (gcugtk::CmdContextGtk *cc):
 		AddRule ("reaction", RuleMustContain, "reaction-arrow");
 		AddRule ("reaction-arrow", RuleMayContain, "reaction-prop");
 		AddRule ("reaction-arrow", RuleMayContain, "reaction-separator");
+		AddRule ("reaction-arrow", RuleMayContain, "reaction-substractor");
 		AddRule ("reaction-arrow", RuleMayContain, "step-counter");
 		AddRule ("reaction-prop", RuleMustBeIn, "reaction-arrow");
 		AddRule ("reaction-prop", RuleMayContain, "molecule");
 		AddRule ("reaction-prop", RuleMayContain, "text");
 		AddRule ("reaction-operator", RuleMustBeIn, "reaction-step");
 		AddRule ("reaction-separator", RuleMustBeIn, "reaction-arrow");
+		AddRule ("reaction-substractor", RuleMustBeIn, "reaction-arrow");
 		AddRule ("step-counter", RuleMustBeIn, "reaction-arrow");
 		AddRule ("reactant", RuleMayContain, "molecule");
 		AddRule ("reactant", RuleMayContain, "text");
@@ -806,17 +817,6 @@ void Application::SaveGcp (string const &filename, Document* pDoc)
 	gtk_recent_manager_add_full (GetRecentManager (), filename.c_str (), &data);
 }
 
-static int	cb_vfs_to_xml (GInputStream *input, char* buf, int nb)
-{
-	GError *error = NULL;
-	int n = g_input_stream_read (input, buf, nb, NULL, &error);
-	if (error) {
-		g_message ("GIO error: %s", error->message);
-		g_error_free (error);
-	}
-	return n;
-}
-
 void Application::OpenGcp (string const &filename, Document* pDoc)
 {
 	xmlDocPtr xml = NULL;
@@ -841,16 +841,7 @@ void Application::OpenGcp (string const &filename, Document* pDoc)
 			g_error_free (error);
 			throw 1;
 		}
-		GInputStream *input = G_INPUT_STREAM (g_file_read (file, NULL, &error));
-		if (error) {
-			g_object_unref (file);
-			g_message ("GIO error: %s\n", error->message);
-			g_error_free (error);
-			throw 1;
-		}
-		xmlKeepBlanksDefault (1); // to be sure we don't loose significant spaces.
-		if (!(xml = xmlReadIO ((xmlInputReadCallback) cb_vfs_to_xml,
-				 (xmlInputCloseCallback) g_input_stream_close, input, filename.c_str (), NULL, 0))) {
+		if (!(xml = ReadXMLDocFromFile (file, filename.c_str (), NULL, NULL))) {
 			g_object_unref (file);
 			throw 1;
 		}
@@ -990,20 +981,39 @@ void Application::OnToolChanged (GtkAction *current)
 		m_pActiveTool->Activate(true);
 }
 
+void Application::OnToolChanged (char const *new_tool_name)
+{
+	Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
+	if (m_pActiveTool) {
+		if (m_pActiveTool->GetName () == new_tool_name)
+			return;
+		if (!m_pActiveTool->Activate(false)) {
+			if (ToolsBox)
+				ToolsBox->OnSelectTool (m_pActiveTool);
+			return;
+		}
+	}
+	m_pActiveTool = m_Tools[new_tool_name];
+	if (ToolsBox)
+		ToolsBox->OnSelectTool (m_pActiveTool);
+	if (m_pActiveTool)
+		m_pActiveTool->Activate(true);
+}
+
 void Application::BuildTools () throw (std::runtime_error)
 {
-	Tools *ToolsBox = new Tools (this);
-	map<int, string>::iterator i, iend = ToolbarNames.end ();
-	list<char const*>::iterator j, jend = UiDescs.end ();
-	string s;
-	GError *error = NULL;
-	gcugtk::UIManager *ToolsManager = new gcugtk::UIManager (gtk_ui_manager_new ());
-	ToolsBox->SetUIManager (ToolsManager);
-	GtkActionGroup *action_group = gtk_action_group_new ("Tools");
-	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
-	gtk_action_group_add_radio_actions (action_group, RadioActions, m_entries, 0, G_CALLBACK (on_tool_changed), this);
-	gtk_ui_manager_insert_action_group (ToolsManager->GetUIManager (), action_group, 0);
-	for (j = UiDescs.begin (); j != jend; j++)
+	Tools *ToolsBox = new Tools (this, m_ToolDescriptions);
+//	map < int, string >::iterator i, iend = ToolbarNames.end ();
+//	list < ToolDesc const * >::iterator j, jend = m_ToolDescriptions.end ();
+//	string s;
+//	GError *error = NULL;
+//	gcugtk::UIManager *ToolsManager = new gcugtk::UIManager (gtk_ui_manager_new ());
+//	ToolsBox->SetUIManager (ToolsManager);
+//	GtkActionGroup *action_group = gtk_action_group_new ("Tools");
+//	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
+//	gtk_action_group_add_radio_actions (action_group, RadioActions, m_entries, 0, G_CALLBACK (on_tool_changed), this);
+//	gtk_ui_manager_insert_action_group (ToolsManager->GetUIManager (), action_group, 0);
+/*	for (j = UiDescs.begin (); j != jend; j++)
 		if (!gtk_ui_manager_add_ui_from_string (ToolsManager->GetUIManager (), *j, -1, &error)) {
 			string what = string ("building user interface failed: ") + error->message;
 			g_error_free (error);
@@ -1013,7 +1023,7 @@ void Application::BuildTools () throw (std::runtime_error)
 		s = "ui/";
 		s += (*i).second;
 		ToolsBox->AddToolbar (s);
-	}
+	}*/
 	m_pActiveTool = m_Tools["Select"];
 	if (m_pActiveTool)
 		m_pActiveTool->Activate(true);
@@ -1182,6 +1192,12 @@ void Application::AddActions (GtkRadioActionEntry const *entries, int nb, char c
 	}
 }
 
+void Application::AddTools (ToolDesc const *tools)
+{
+	// just storing at this point
+	m_ToolDescriptions.push_back (tools);
+}
+
 void Application::RegisterToolbar (char const *name, int index)
 {
 	if (ToolbarNames[index] == "")
