@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction-arrow.h
  *
- * Copyright (C) 2004-2012 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2014 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -53,6 +53,7 @@ class ReactionArrowStep; //private class
 Arrow class for arrows used in chemical reactions.*/
 class ReactionArrow: public Arrow, public gcu::DialogOwner
 {
+friend class ReactionArrowPrivate;
 public:
 /*!
 */
@@ -104,6 +105,15 @@ arrow if any.
 */
 	void Move (double x, double y, double z = 0);
 /*!
+@param xstart the x coordinate of the start point.
+@param ystart the y coordinate of the start point.
+@param xend the x coordinate of the end point.
+@param yend the y coordinate of the end point.
+
+Sets the position and length of an arrow. Overrides and calls Arrow::SetCoords().
+*/
+	void SetCoords (double xstart, double ystart, double xend, double yend);
+/*!
 @param state: the selection state of the arrow.
 
 Used to set the selection state of the arrow inside the widget.
@@ -174,7 +184,6 @@ private:
 
 GCU_PROP (unsigned, MaxLinesAbove)
 GCU_PROP (NumberingScheme, NumberingScheme);
-GCU_RO_PROP (double, MinLength);
 };
 
 }	//	namespace gcp
