@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -85,15 +85,17 @@ bool Reaction::Build (std::set < Object * > const &Children) throw (invalid_argu
 	double zf = pTheme->GetZoomFactor ();
 	gccv::Rect *rect;
 	for (i = Children.begin (); i != iend; i++) {
+		unsigned type = (*i)->GetType();
 		// It might be better to use the objects coordinates there
 		pData->GetObjectBounds (*i, &Objects[*i]);
 		// Search arrows
-		if ((*i)->GetType() == ReactionArrowType)
+		if (type == ReactionArrowType)
 			Arrows.push_front ((ReactionArrow*) (*i));
-		else if ((*i)->GetType () == MoleculeType || (*i)->GetType () == MechanismStepType
-		         || (*i)->GetType () == TextType)
+		else if (type == MoleculeType || type == MechanismStepType
+		         || type == TextType || type == gcu::MesomeryType)
 			Others.insert (*i);
-		else return false;
+		else
+			return false;
 	}
 	/* sort objects according their position relative to each arrow, using string, with
 	 * one char per arrow, 't' means on tail side, 'h', header side, and 'o' other.
@@ -138,7 +140,8 @@ bool Reaction::Build (std::set < Object * > const &Children) throw (invalid_argu
 		double dx, dy, dl;
 		dx = x1 - x0;
 		dy = y1 - y0;
-		dl = sqrt (dx * dx + dy * dy) / pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
+		// we need more than one arrow padding to avoid issues with parallel arrows (o letters).
+		dl = sqrt (dx * dx + dy * dy) / 3. / pTheme->GetArrowPadding () * pTheme->GetZoomFactor ();
 		dx /= dl;
 		dy /= dl;
 		x0 -= dx;
@@ -205,87 +208,25 @@ bool Reaction::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Obj)
 	if (IsLocked ())
 		return false;
 	if (Signal == OnChangedSignal) {
-		Document *pDoc = (Document*) GetDocument ();
-		View *pView = pDoc->GetView ();
-		Theme *pTheme = pDoc->GetTheme ();
-		WidgetData  *pData= (WidgetData*)g_object_get_data(G_OBJECT(pDoc->GetWidget ()), "data");
 		map<Object*, gccv::Rect> Objects;
 		map<double, Object*> Children;
 		list<Object*> Operators;
-		gccv::Rect rect;
 		map<string, Object*>::iterator i;
 		Object *pObj = GetFirstChild (i);
 		ReactionArrow *arrow;
 		ReactionStep *step;
 		list<ReactionArrow *> IsolatedArrows;
-		double x0, y0, x1, y1, x, y, x2, y2, xpos, ypos, l;
-		bool horiz, has_start;
+		bool has_start;
 		// It is assume we'll find only one arrow!
 		while (pObj) {
 			if (pObj->GetType () == ReactionArrowType) {
 				arrow = reinterpret_cast<ReactionArrow*> (pObj);
 				has_start = false;
-				arrow->GetCoords (&x0, &y0, &x1, &y1);
-				x = x1 - x0;
-				y = y1 - y0;
-				l = sqrt (x * x + y * y);
-				x /= l;
-				y /= l;
-				if ((fabs (x) > 1e-5) && (fabs (y) > 1e-5))
-					horiz = (fabs (x) > fabs (y));
-				else if (fabs (x) > 1e-5)
-					horiz = true;
-				else
-					horiz = false;
 				step = static_cast < ReactionStep * > (arrow->GetStartStep ());
-				if (step) {
+				if (step)
 					has_start = true;
-					pData->GetObjectBounds (step, &rect);
-					x2 = (rect.x0 + rect.x1) / 2;
-					y2 = step->GetYAlign () * pTheme->GetZoomFactor ();
-					xpos = rect.x1 - x2;
-					ypos = rect.y1 - y2;
-					if (horiz) {
-						l = xpos + pTheme->GetArrowPadding ();
-						if (x < 0)
-							l = -l;
-						x2 += l;
-						y2 += l * y / x;
-					} else {
-						l = ypos + pTheme->GetArrowPadding ();
-						if (y < 0)
-							l = -l;
-						x2 += l * x / y;
-						y2 += l;
-					}
-					x1 += xpos = x2 / pTheme->GetZoomFactor () - x0;
-					y1 += ypos = y2 / pTheme->GetZoomFactor () - y0;
-					arrow->Move (xpos, ypos);
-					pView->Update (arrow);
-				}
 				step = static_cast < ReactionStep * > (arrow->GetEndStep ());
-				if (step) {
-					pData->GetObjectBounds (step, &rect);
-					x2 = (rect.x0 + rect.x1) / 2;
-					y2 = step->GetYAlign () * pTheme->GetZoomFactor ();
-					if (horiz) {
-						xpos = rect.x1 - x2;
-						l = xpos + pTheme->GetArrowPadding ();
-						if (x < 0)
-							l = -l;
-						x2 -= l;
-						y2 -= l * y / x;
-					} else {
-						ypos = rect.y1 - y2;
-						l = ypos + pTheme->GetArrowPadding ();
-						if (y < 0)
-							l = -l;
-						x2 -= l * x / y;
-						y2 -= l;
-					}
-					step->Move (x1 - x2 / pTheme->GetZoomFactor (), y1 - y2 / pTheme->GetZoomFactor ());
-					pView->Update (step);
-				} else if (!has_start)
+				if (!step && !has_start)
 					IsolatedArrows.push_front (arrow);
 			}
 			pObj = GetNextChild (i);
@@ -296,6 +237,8 @@ bool Reaction::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Obj)
 		}
 		if (!HasChildren ())
 			delete this;
+		else
+			Align ();
 	}
 	return true;
 }
