@@ -39,7 +39,6 @@
 #include <gcu/objprops.h>
 #include <gcu/xml-utils.h>
 #include <glib/gi18n-lib.h>
-#include <sstream>
 #include <stdexcept>
 #include <cmath>
 #include <cstring>
@@ -168,7 +167,7 @@ bool SaveStruct::Save (xmlDocPtr xml, xmlNodePtr node, unsigned &index, string c
 		f = static_cast <gccv::FamilyTextTag *> (m_tag)->GetFamily ().c_str ();
 		ef = m_end;
 		if (es >= ef) {
-			char *str = g_strdup_printf ("%s, %g", f, (double) n / PANGO_SCALE);
+			char *str = g_strdup_printf ("%s %g", f, (double) n / PANGO_SCALE);
 			child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("font"), NULL);
 			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("name"), reinterpret_cast <xmlChar const *> (str));
 			g_free (str);
@@ -178,7 +177,7 @@ bool SaveStruct::Save (xmlDocPtr xml, xmlNodePtr node, unsigned &index, string c
 		n = static_cast <gccv::SizeTextTag *> (m_tag)->GetSize ();
 		es = m_end;
 		if (ef >= es) {
-			char *str = g_strdup_printf ("%s, %g", f, (double) n / PANGO_SCALE);
+			char *str = g_strdup_printf ("%s %g", f, (double) n / PANGO_SCALE);
 			child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ("font"), NULL);
 			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("name"), reinterpret_cast <xmlChar const *> (str));
 			g_free (str);
@@ -551,6 +550,7 @@ bool Text::Load (xmlNodePtr node)
 {
 	if (!TextObject::Load (node))
 		return false;
+	Document *doc = static_cast <Document*> (GetDocument ());
 	xmlChar *buf = xmlGetProp (node, (xmlChar const *) "justification");
 	if (buf) {
 		if (!strcmp ((char const *) buf, "justify"))
@@ -609,7 +609,8 @@ bool Text::Load (xmlNodePtr node)
 		text->SetInterline (m_Interline);
 	}
 	m_bLoading = false;
-	GetDocument ()->ObjectLoaded (this);
+	doc->ObjectLoaded (this);
+	doc->GetView ()->AddObject (this);
 	return true;
 }
 
@@ -927,10 +928,8 @@ void Text::AddItem ()
 
 void Text::UpdateItem ()
 {
-	if (!m_Item) {
+	if (!m_Item)
 		AddItem ();
-		return;
-	}
 	Document *doc = static_cast <Document*> (GetDocument ());
 	Theme *theme = doc->GetTheme ();
 	reinterpret_cast <gccv::Text *> (m_Item)->SetPosition (m_x * theme->GetZoomFactor (), m_y * theme->GetZoomFactor ());
@@ -978,7 +977,7 @@ void Text::SetSelected (int state)
 		color = DeleteColor;
 		break;
 	default:
-		color = GO_COLOR_WHITE;
+		color = 0;
 		break;
 	}
 	dynamic_cast <gccv::LineItem *> (m_Item)->SetLineColor (color);
@@ -998,70 +997,6 @@ double Text::GetYAlign ()
 	return m_y;
 }
 
-std::string Text::GetProperty (unsigned property) const
-{
-	switch (property) {
-	case GCU_PROP_POS2D: {
-		std::ostringstream str;
-		gcu::Document *doc = GetDocument ();
-		str.precision (12);
-		if (doc)
-			str << m_x / doc->GetScale () << " " << m_y / doc->GetScale ();
-		else
-			str << m_x << " " << m_y;
-		return str.str ();
-	}
-	case GCU_PROP_TEXT_MARKUP: {
-		xmlDocPtr xml = xmlNewDoc ((xmlChar*) "1.0");
-		char *buf;
-		int n;
-		//FIXME: do something if an error occurs
-
-		xmlFreeNode (xmlDocSetRootElement (xml,  Save (xml)));
-		xmlDocDumpMemory (xml, reinterpret_cast < xmlChar ** > (&buf), &n);
-		std::string res (buf, n);
-		xmlFree (buf);
-		xmlFreeDoc (xml);
-		return res;
-
-	}
-	case GCU_PROP_TEXT_TEXT:
-		return m_buf;
-	case GCU_PROP_TEXT_ALIGNMENT:
-		switch (m_Anchor) {
-		case gccv::AnchorLineEast:
-		case gccv::AnchorNorthEast:
-		case gccv::AnchorEast:
-		case gccv::AnchorSouthEast:
-			return "right";
-		case gccv::AnchorNorthWest:
-		case gccv::AnchorLineWest:
-		case gccv::AnchorWest:
-		case gccv::AnchorSouthWest:
-			return "left";
-		case gccv::AnchorNorth:
-		case gccv::AnchorLine:
-		case gccv::AnchorCenter:
-		case gccv::AnchorSouth:
-			return "center";
-		}
-		break;
-	case GCU_PROP_TEXT_JUSTIFICATION:
-		switch (m_Justification) {
-		case GTK_JUSTIFY_RIGHT:
-			return  "right";
-		case GTK_JUSTIFY_LEFT:
-			return  "left";
-		case GTK_JUSTIFY_CENTER:
-			return  "center";
-		case GTK_JUSTIFY_FILL:
-			return "justify";
-		}
-		break;
-	}
-	return "";
-}
-
 bool Text::SetProperty (unsigned property, char const *value)
 {
 	switch (property) {
@@ -1078,8 +1013,6 @@ bool Text::SetProperty (unsigned property, char const *value)
 	}
 	case GCU_PROP_TEXT_MARKUP: {
 		xmlDocPtr xml = xmlParseMemory (value, strlen (value));
-		if (xml == NULL)
-			break;
 		xmlNodePtr node = xml->children->children;
 		unsigned pos = 0;
 		m_buf.clear ();
@@ -1091,7 +1024,6 @@ bool Text::SetProperty (unsigned property, char const *value)
 		}
 		m_bLoading = false;
 		// FIXME: implement
-		xmlFreeDoc (xml);
 		break;
 	}
 	case GCU_PROP_TEXT_TEXT:
