@@ -92,6 +92,13 @@ View::View (Document *pDoc, bool Embedded):
 	pango_font_description_set_stretch (m_PangoSmallFontDesc, pTheme->GetFontStretch ());
 	pango_font_description_set_size (m_PangoSmallFontDesc, pTheme->GetFontSize () * 2 / 3);
 	m_sSmallFontName = pango_font_description_to_string (m_PangoSmallFontDesc);
+	m_PangoTextFontDesc = pango_font_description_new ();
+	pango_font_description_set_family (m_PangoTextFontDesc, pTheme->GetTextFontFamily ());
+	pango_font_description_set_style (m_PangoTextFontDesc, pTheme->GetTextFontStyle ());
+	pango_font_description_set_weight (m_PangoTextFontDesc, pTheme->GetTextFontWeight ());
+	pango_font_description_set_variant (m_PangoTextFontDesc, pTheme->GetTextFontVariant ());
+	pango_font_description_set_stretch (m_PangoTextFontDesc, pTheme->GetTextFontStretch ());
+	pango_font_description_set_size (m_PangoTextFontDesc, pTheme->GetTextFontSize ());
 	m_width = 400;
 	m_height = 300;
 	m_ActiveRichText = NULL;
@@ -122,6 +129,7 @@ View::~View ()
 		g_free (m_sSmallFontName);
 	pango_font_description_free (m_PangoFontDesc);
 	pango_font_description_free (m_PangoSmallFontDesc);
+	pango_font_description_free (m_PangoTextFontDesc);
 	delete m_UIManager;
 	// we don't need to delete the canvas, since destroying the widget does the job.
 }
@@ -891,10 +899,8 @@ void View::EnsureSize ()
 	m_Canvas->GetRoot ()->GetBounds (x1, y1, x2, y2);
 	if (x1 < 0.) x2 -= x1;
 	if (y1 < 0.) y2 -= y1;
-	if (x2 <= 0. || y2 <= 0.) {
-		gtk_widget_set_size_request (m_pWidget, -1, -1);
+	if (x2 <= 0. || y2 <= 0.)
 		return;
-	}
 	if ((x2 != m_width) || (y2 != m_height)) {
 		m_width = x2;
 		m_height = y2;
@@ -931,6 +937,7 @@ void View::UpdateTheme ()
 		g_free (m_sSmallFontName);
 	pango_font_description_free (m_PangoFontDesc);
 	pango_font_description_free (m_PangoSmallFontDesc);
+	pango_font_description_free (m_PangoTextFontDesc);
 	Theme *pTheme = m_pDoc->GetTheme ();
 	m_PangoFontDesc = pango_font_description_new ();
 	pango_font_description_set_family (m_PangoFontDesc, pTheme->GetFontFamily ());
@@ -948,6 +955,13 @@ void View::UpdateTheme ()
 	pango_font_description_set_stretch (m_PangoSmallFontDesc, pTheme->GetFontStretch ());
 	pango_font_description_set_size (m_PangoSmallFontDesc, pTheme->GetFontSize () * 2 / 3);
 	m_sSmallFontName = pango_font_description_to_string (m_PangoSmallFontDesc);
+	m_PangoTextFontDesc = pango_font_description_new ();
+	pango_font_description_set_family (m_PangoTextFontDesc, pTheme->GetTextFontFamily ());
+	pango_font_description_set_style (m_PangoTextFontDesc, pTheme->GetTextFontStyle ());
+	pango_font_description_set_weight (m_PangoTextFontDesc, pTheme->GetTextFontWeight ());
+	pango_font_description_set_variant (m_PangoTextFontDesc, pTheme->GetTextFontVariant ());
+	pango_font_description_set_stretch (m_PangoTextFontDesc, pTheme->GetTextFontStretch ());
+	pango_font_description_set_size (m_PangoTextFontDesc, pTheme->GetTextFontSize ());
 	Update (m_pDoc);
 }
 
