@@ -33,6 +33,7 @@
 #include "zoomdlg.h"
 #include <gcugtk/dialog.h>
 #include <gcugtk/filechooser.h>
+#include <gcugtk/message.h>
 #include <gcugtk/print-setup-dlg.h>
 #include <gcugtk/ui-manager.h>
 #include <gcugtk/stringinputdlg.h>
@@ -99,7 +100,7 @@ static void on_destroy (G_GNUC_UNUSED GtkWidget* widget, gcp::Window* Win)
 
 static bool on_delete_event (G_GNUC_UNUSED GtkWidget* widget, G_GNUC_UNUSED GdkEvent *event, gcp::Window* Win)
 {
-	return !Win->VerifySaved ();
+	return !Win->Close ();
 }
 
 static void on_file_new(G_GNUC_UNUSED GtkWidget* widget, gcp::Window* Win)
@@ -405,7 +406,7 @@ static GtkActionEntry entries[] = {
 		  { "Zoom", NULL, N_("_Zoom to...%"), "<control>M",
 			  N_("Open Zoom Dialog Box"), G_CALLBACK (on_zoom) },
   { "ToolsMenu", NULL, N_("_Tools"), NULL, NULL, NULL },
-	  { "ImportMol", NULL, N_("_Import molecule"), NULL,
+	  { "ImportMol", NULL, N_("_Import molecule..."), NULL,
 		  N_("Import a molecule either from InChI or SMILES"), G_CALLBACK (WindowPrivate::ImportMolecule) },
   { "WindowsMenu", NULL, N_("_Windows"), NULL, NULL, NULL },
   { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
@@ -598,7 +599,7 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 	GtkScrolledWindow* scroll = (GtkScrolledWindow*) gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (scroll, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (scroll, GTK_SHADOW_IN);
-	gtk_scrolled_window_add_with_viewport (scroll, w);
+	gtk_container_add (GTK_CONTAINER (scroll), w);
 	gtk_widget_set_size_request (GTK_WIDGET (scroll), 408, 308);
 	gtk_widget_show (GTK_WIDGET (scroll));
 	gtk_container_add (GTK_CONTAINER (grid), GTK_WIDGET (scroll));
@@ -781,14 +782,13 @@ bool Window::VerifySaved ()
 	if (!m_Document->GetDirty ())
 		return true;
 	int res;
-	GtkWidget* mbox;
 	do {
 		gchar* str = g_strdup_printf (_("\"%s\" has been modified.  Do you wish to save it?"), m_Document->GetTitle ());
-		mbox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
+		gcugtk::Message *box = new gcugtk::Message (static_cast < gcugtk::Application * > (GetApplication ()),
+		                                            str, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, GetWindow (), true);
+		gtk_dialog_add_button (GTK_DIALOG (box->GetWindow ()),  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+		res = box->Run ();
 		g_free (str);
-		gtk_dialog_add_button (GTK_DIALOG (mbox),  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-		res = gtk_dialog_run (GTK_DIALOG (mbox));
-		gtk_widget_destroy (mbox);
 		if (res == GTK_RESPONSE_YES)
 			OnSave ();
 		while (gtk_events_pending ()) // no idea why this is needed
