@@ -65,7 +65,8 @@ public:
 	static void ValueChanged (AtomsDlg *pBox, unsigned row, unsigned column);
 	static void RowSelected (AtomsDlg *pBox, int row);
 	static void ElementChanged (AtomsDlg *pBox, unsigned Z);
-	static void ColorSet (GtkColorButton *btn, AtomsDlg *pBox);
+	static void SetElement (unsigned i, AtomsDlg *pBox);
+	static void ColorSet (GtkColorChooser *btn, AtomsDlg *pBox);
 	static void SetColor (unsigned i, AtomsDlg *pBox);
 	static void ColorToggled (GtkToggleButton *btn, AtomsDlg *pBox);
 	static void ChargeChanged (GtkSpinButton *btn, AtomsDlg *pBox);
@@ -89,7 +90,7 @@ void AtomsDlgPrivate::AddRow (AtomsDlg *pBox)
 		new_atom->SetRadius (pBox->m_Radius);
 		new_atom->SetEffectiveRadiusRatio (gtk_spin_button_get_value (pBox->ScaleBtn) / 100.);
 		GdkRGBA rgba;
-		gtk_color_button_get_rgba (pBox->AtomColor, &rgba);
+		gtk_color_chooser_get_rgba (pBox->AtomColor, &rgba);
 		new_atom->SetColor (rgba.red, rgba.green, rgba.blue, rgba.alpha);
 	}
 	unsigned new_row = gcr_grid_append_row (pBox->m_Grid,
@@ -168,7 +169,7 @@ void AtomsDlgPrivate::RowSelected (AtomsDlg *pBox, int row)
 		g_signal_handler_block (pBox->AtomColor, pBox->m_ColorSignalID);
 		GdkRGBA rgba, color;
 		pBox->m_Atoms[row]->GetColor (rgba);
-		gtk_color_button_set_rgba (pBox->AtomColor, &rgba);
+		gtk_color_chooser_set_rgba (pBox->AtomColor, &rgba);
 		g_signal_handler_unblock (pBox->AtomColor, pBox->m_ColorSignalID);
 		if (pBox->m_nElt) {
 			double *Colors = Element::GetElement (pBox->m_nElt)->GetDefaultColor ();
@@ -207,9 +208,16 @@ void AtomsDlgPrivate::RowSelected (AtomsDlg *pBox, int row)
 	}
 }
 
+void AtomsDlgPrivate::SetElement (unsigned i, AtomsDlg *pBox)
+{
+	pBox->m_Atoms[i]->SetZ (pBox->m_nElt);
+	gcr_grid_set_string (pBox->m_Grid, i, 0, pBox->m_nElt > 0? Element::GetElement (pBox->m_nElt)->GetSymbol (): _("Unknown"));
+	pBox->m_Atoms[i]->SetRadius (pBox->m_Radius);
+	pBox->m_Atoms[i]->SetColor (pBox->m_RGBA.red, pBox->m_RGBA.green, pBox->m_RGBA.blue, pBox->m_RGBA.alpha);
+}
+
 void AtomsDlgPrivate::ElementChanged (AtomsDlg *pBox, unsigned Z)
 {
-	GdkRGBA color;
 	if ((pBox->m_nElt = Z)) {
 		pBox->m_Radii = Element::GetElement (Z)->GetRadii ();
 		if ((pBox->m_RadiusType == GCU_IONIC) && (pBox->m_Charge == 0)) {
@@ -219,21 +227,17 @@ void AtomsDlgPrivate::ElementChanged (AtomsDlg *pBox, unsigned Z)
 			pBox->PopulateRadiiMenu ();
 		gtk_toggle_button_set_active (pBox->CustomColor, false);
 		double *Colors = Element::GetElement (Z)->GetDefaultColor ();
-		color.red = Colors[0];
-		color.green = Colors[1];
-		color.blue = Colors[2];
-		color.alpha = 1.;
-		gtk_color_button_set_rgba (pBox->AtomColor, &color);
+		pBox->m_RGBA.red = Colors[0];
+		pBox->m_RGBA.green = Colors[1];
+		pBox->m_RGBA.blue = Colors[2];
+		pBox->m_RGBA.alpha = 1.;
+		gtk_color_chooser_set_rgba (pBox->AtomColor, &pBox->m_RGBA);
 	} else {
 		pBox->m_Radii = NULL;
 		gtk_toggle_button_set_active (pBox->CustomColor, true);
-		gtk_color_button_get_rgba (pBox->AtomColor, &color);
 	}
 	if (pBox->m_AtomSelected >= 0) {
-		pBox->m_Atoms[pBox->m_AtomSelected]->SetZ (Z);
-		gcr_grid_set_string (pBox->m_Grid, pBox->m_AtomSelected, 0, Z > 0? Element::GetElement (Z)->GetSymbol (): _("Unknown"));
-		pBox->m_Atoms[pBox->m_AtomSelected]->SetRadius (pBox->m_Radius);
-		pBox->m_Atoms[pBox->m_AtomSelected]->SetColor (color.red, color.green, color.blue, color.alpha);
+		gcr_grid_for_each_selected (pBox->m_Grid, reinterpret_cast < GridCb > (SetElement), pBox);
 		pBox->m_pDoc->Update ();
 		pBox->m_pDoc->SetDirty (true);
 	}
@@ -241,13 +245,13 @@ void AtomsDlgPrivate::ElementChanged (AtomsDlg *pBox, unsigned Z)
 
 void AtomsDlgPrivate::SetColor (unsigned i, AtomsDlg *pBox)
 {
-		pBox->m_Atoms[i]->SetColor (pBox->m_RGBA.red, pBox->m_RGBA.green, pBox->m_RGBA.blue, pBox->m_RGBA.alpha);
+	pBox->m_Atoms[i]->SetColor (pBox->m_RGBA.red, pBox->m_RGBA.green, pBox->m_RGBA.blue, pBox->m_RGBA.alpha);
 }
 
-void AtomsDlgPrivate::ColorSet (GtkColorButton *btn, AtomsDlg *pBox)
+void AtomsDlgPrivate::ColorSet (GtkColorChooser *btn, AtomsDlg *pBox)
 {
 	if (pBox->m_AtomSelected >= 0) {
-		gtk_color_button_get_rgba (btn, &pBox->m_RGBA);
+		gtk_color_chooser_get_rgba (btn, &pBox->m_RGBA);
 		gcr_grid_for_each_selected (pBox->m_Grid, reinterpret_cast < GridCb > (SetColor), pBox);
 		pBox->m_pDoc->Update ();
 		pBox->m_pDoc->SetDirty (true);
@@ -434,7 +438,7 @@ AtomsDlg::AtomsDlg (Application *App, Document* pDoc): gcugtk::Dialog (App, UIDI
 		m_Atoms[gcr_grid_append_row (m_Grid, ((*i)->GetZ () > 0)? Element::Symbol ((*i)->GetZ ()): _("Unknown"), (*i)->x (), (*i)->y (), (*i)->z ())] = *i;
 	if (Atoms->empty ())
 		gtk_widget_set_sensitive (DeleteAllBtn, false);
-	AtomColor = GTK_COLOR_BUTTON (GetWidget ("color"));
+	AtomColor = GTK_COLOR_CHOOSER (GetWidget ("color"));
 	m_ColorSignalID = g_signal_connect (G_OBJECT (AtomColor), "color-set", G_CALLBACK (AtomsDlgPrivate::ColorSet), this);
 	CustomColor = GTK_TOGGLE_BUTTON (GetWidget ("custom_color"));
 	gtk_toggle_button_set_active (CustomColor, true);
