@@ -26,6 +26,7 @@
 #define GCU_ATOM_H
 
 #include "object.h"
+#include "macros.h"
 #include <glib.h>
 #include <map>
 #include <vector>
@@ -282,6 +283,23 @@ and return its result.
 */
 	std::string Name ();
 
+/*!
+@param a: the a parameter of the unit cell.
+@param b: the b parameter of the unit cell.
+@param c: the c parameter of the unit cell.
+@param alpha: the alpha angle of the unit cell.
+@param beta: the beta angle of the unit cell.
+@param gamma: the gamma angle of the unit cell.
+
+Converts the coordinates of the atom from net related ones to cartesian. Initially, atoms are defined by their
+position relative to the unit cell and the coordinates must be transformed to the cartesian ones before
+displaying the atom.
+*/
+	void NetToCartesian (double a, double b, double c, double alpha, double beta, double gamma);
+
+private:
+	void AChanged ();
+
 protected:
 /*!
 The atomic number of the Atom.
@@ -307,6 +325,9 @@ The charge of the Atom.
 The Bond instances of the Atom. The index of the map is a pointer to the other end of the Bond.
 */
 	std::map<Atom*, Bond*> m_Bonds;
+
+GCU_PROP_FULL (int, A, AChanged) // nucleon number, 0 means natural or not specified.
+
 };
 
 /*!\class AtomPair gcu/atom.h
