@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -25,6 +25,9 @@
 #ifndef GCU_WINDOW_H
 #define GCU_WINDOW_H
 
+#include "macros.h"
+#include "ui-builder.h"
+
 /*!\file*/
 namespace gcu {
 class UIManager;
@@ -73,6 +76,7 @@ protected:
 The gcugtk::UIManager associated with the window.
 */
 	UIManager* m_UIManager;
+GCU_PROT_POINTER_PROP (UIBuilder, Builder)
 };
 
 }
